dev library

Dev/JIT-only entrypoint for package:conduit_config.

Re-exports the mirror-based Configuration compiler. Production AOT-compiled code should import package:conduit_config/conduit_config.dart instead.

Classes

APIConfiguration
A Configuration to represent an external HTTP API.
Configuration
Subclasses of Configuration read YAML strings and files, assigning values from the YAML document to properties of an instance of this type.
ConfigurationCompiler
Registers Configuration subclasses with the JIT/dev mirror fallback. Under AOT, the build_runner-generated bootstrap() installs the registry directly and this class is unreachable.
ConfigurationError
Thrown when Configuration subclass is invalid and requires a change in code.
ConfigurationException
Thrown when reading data into a Configuration fails.
ConfigurationItemAttribute
Configuration properties may be attributed with these.
ConfigurationRuntime
DatabaseConfiguration
A Configuration to represent a database connection configuration.

Enums

ConfigurationItemAttributeType
Possible options for a configuration item property's optionality.